#!/bin/bash

id grid > /dev/null 2>&1
if [ $? -eq 0 ]; then
    gridsid=`su - grid -c 'echo $ORACLE_SID'`
    gridlsn=`ps -wwfu grid  | grep -v grep | grep tnslsnr | awk '{print $9}' | tr A-Z a-z`
    gridHome=`su - grid -c 'echo $ORACLE_HOME'`
    scanlis=`su - grid -c "srvctl config scan_listener" | grep 'SCAN Listener' | awk '{print $3}' | tr A-Z a-z`
fi

oraclesid=`su - oracle -c 'echo $ORACLE_SID'`
host=`hostname`
oraclelsn=`ps -wwfu oracle  | grep -v grep | grep tnslsnr | awk '{print $9}' | tr A-Z a-z`
cleanDBLog=/tmp/cleanDBLog.log
sql=/tmp/getparameter.sql
sqllog=/tmp/getparameter.log

#####################################
# Function:    getparameter
# Description: ȡdiagnostic_dest
#                  db_unique_name
#                   audit_file_destֵ
#####################################
function getparameter
{    
    user=$1
    parameter=$2
    
    echo "set linesize 200" > $sql
    echo "set pagesize 4000" >> $sql
    echo "set long 4000" >> $sql
    echo "column name format a40" >> $sql
    echo "column value format a100" >> $sql
    echo "select name,value from v\$parameter where name ='$parameter';" >> $sql
    echo "exit" >> $sql
    chmod 604 $sql
    su - $user -c "sqlplus / as sysdba @${sql}" > $sqllog
    param=`grep "$parameter" $sqllog | awk  '{print $2}'`
    echo $param
}


#####################################
# Function:    cleanGirdAudit
# Description:                  
#####################################
function cleanGirdAudit
{
    echo "-------------------------cleanGirdAudit--------------------------" >>$cleanDBLog
    param=`getparameter grid audit_file_dest`
    cat $sqllog >>$cleanDBLog
    if [ ! -e ${param} ];then
        echo "param is null" >>$cleanDBLog
        return 1
    fi
    find "$param" -type f -mtime +6 | xargs rm -rf >>$cleanDBLog
    echo "-------------------------cleanGirdAudit END--------------------------" >>$cleanDBLog    
}

#####################################
# Function:    cleanOracleAudit
# Description:                  
#####################################
function cleanOracleAudit
{
    echo "-------------------------cleanOracleAudit--------------------------" >>$cleanDBLog
    param=`getparameter oracle audit_file_dest`
    cat $sqllog >>$cleanDBLog
    if [ ! -e ${param} ];then
        echo "param is null" >>$cleanDBLog
        return 1
    fi
    find "$param" -type f -mtime +6 | xargs rm -rf >>$cleanDBLog
    echo "-------------------------cleanOracleAudit END--------------------------" >>$cleanDBLog  
}

#####################################
# Function:    cleanOracleTrace
# Description:                  
#####################################
function cleanOracleTrace
{
    echo "-------------------------cleanOracleTrace--------------------------" >>$cleanDBLog
    param=`getparameter oracle diagnostic_dest`
    cat $sqllog >>$cleanDBLog
    if [ ! -e ${param} ];then
        echo "param is null" >>$cleanDBLog
        return 1
    fi    
    dbname=`getparameter oracle db_unique_name | tr '[A-Z]' '[a-z]'` 
    cat $sqllog >>$cleanDBLog
    if [ "X${dbname}" == "X" ];then
        echo "dbname is null" >>$cleanDBLog
        return 1
    fi    
    find "$param/diag/rdbms/$dbname/$oraclesid/trace/" -type f -mtime +6 | grep -v alert.*.log| xargs rm -rf >>$cleanDBLog
    find "$param/diag/rdbms/$dbname/$oraclesid/trace/" -type d -mtime +6 | grep cdmp| xargs rm -rf >>$cleanDBLog     
    find "$param/diag/rdbms/$dbname/$oraclesid/alert/" -type f -mtime +6 | xargs rm -rf >>$cleanDBLog 
    echo "-------------------------cleanOracleTrace END--------------------------" >>$cleanDBLog 
}


#####################################
# Function:    cleanGridTrace
# Description:                  
#####################################
function cleanGridTrace
{
    echo "-------------------------cleanGridTrace--------------------------" >>$cleanDBLog
    param=`getparameter grid diagnostic_dest`
    cat $sqllog >>$cleanDBLog
    if [ ! -e ${param} ];then
        echo "param is null" >>$cleanDBLog
        return 1
    fi
    
    find "$param/diag/asm/+asm/$gridsid/trace/" -type f -mtime +6 | grep -v alert.*.log| xargs rm -rf >>$cleanDBLog
    find "$param/diag/asm/+asm/$gridsid/trace/" -type d -mtime +6 | grep cdmp| xargs rm -rf >>$cleanDBLog     
    find "$param/diag/asm/+asm/$gridsid/alert/" -type f -mtime +6 | xargs rm -rf >>$cleanDBLog
    echo "-------------------------cleanGridTrace END--------------------------" >>$cleanDBLog  
}


#####################################
# Function:  cleanOracleListernerLog
# Description:                  
#####################################
function cleanOracleListernerLog
{
    echo "-------------------------cleanOracleListernerLog--------------------------" >>$cleanDBLog  
    param=`getparameter oracle diagnostic_dest`
    cat $sqllog >>$cleanDBLog
    if [ ! -e ${param} ];then
        echo "param is null" >>$cleanDBLog
        return 1
    fi
    
    for lsn in $oraclelsn
    do
        find "$param/diag/tnslsnr/$host/$lsn/alert/" -type f -mtime +6 | xargs rm -rf >>$cleanDBLog
        find "$param/diag/tnslsnr/$host/$lsn/trace/" -type f -mtime +6 | xargs rm -rf >>$cleanDBLog
    done
    echo "-------------------------cleanOracleListernerLog END--------------------------" >>$cleanDBLog  
}

#####################################
# Function:    cleanGridListernerLog
# Description:                  
#####################################
function cleanGridListernerLog
{
    echo "-------------------------cleanGridListernerLog--------------------------" >>$cleanDBLog  
    param=`getparameter grid diagnostic_dest`
    cat $sqllog >>$cleanDBLog
    if [ ! -e ${param} ];then
        echo "param is null" >>$cleanDBLog
        return 1
    fi
    
    for lsn in $gridlsn
    do    
        if [ "${scanlis}" != "${lsn}" ];then
            find "$param/diag/tnslsnr/$host/$lsn/alert/" -type f -mtime +6 | xargs rm -rf >>$cleanDBLog  
            find "$param/diag/tnslsnr/$host/$lsn/trace/" -type f -mtime +6 | xargs rm -rf >>$cleanDBLog  
        fi
    done 
    
    #delete scan listener log
    if [ "X${scanlis}" != "X"  ];then
        find "$gridHome/log/diag/tnslsnr/$host/$scanlis/trace/" -type f -mtime +6 | xargs rm -rf >>$cleanDBLog  
        find "$gridHome/log/diag/tnslsnr/$host/$scanlis/alert/" -type f -mtime +6 | xargs rm -rf >>$cleanDBLog  
    fi
    echo "-------------------------cleanGridListernerLog END--------------------------" >>$cleanDBLog  
}

#####################################
# Function:    main
# Description:                  
#####################################
function main
{
    echo "`date +"%Y-%m-%d %H:%M:%S"`" >$cleanDBLog
    id grid > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        cleanGridListernerLog
        cleanGirdAudit
        cleanGridTrace
    fi
    
    cleanOracleAudit
    cleanOracleListernerLog
    cleanOracleTrace
}

#жoracleûǷн̣ûǱ
ps -wwfu oracle > /dev/null 2>&1
if [ $? -eq 0 ]; then
    main
fi
